
This repository contains a Python packages to assist with the calibration of ship-mounted fisheries omni-sonar systems.

# Installation

Install using pip:

```
pip install sonarcal
```

or upgrade:

```
pip install sonarcal --upgrade
```

# Documentation

The user and technical manuals are available [here](https://aqualyd-limited.github.io/sonarCal/).
